@@ -142,6 +142,13 @@ class TestDatabricks(Validator):
             """SELECT raw:`zip code`, raw:`fb:testid`, raw:store['bicycle'], raw:store["zip code"]""",
             """SELECT raw:["zip code"], raw:["fb:testid"], raw:store.bicycle, raw:store["zip code"]""",
         )
+        self.validate_all(
+            "SELECT col:`fr'uit`",
+            write={
+                "databricks": """SELECT col:["fr'uit"]""",
+                "postgres": "SELECT JSON_EXTRACT_PATH(col, 'fr''uit')",
+            },
+        )
 
     def test_datediff(self):
         self.validate_all(
@@ -256,3 +263,11 @@ class TestDatabricks(Validator):
                 "databricks": "WITH x AS (SELECT 1) SELECT * FROM x",
             },
         )
+
+    def test_streaming_tables(self):
+        self.validate_identity(
+            "CREATE STREAMING TABLE raw_data AS SELECT * FROM STREAM READ_FILES('abfss://container@storageAccount.dfs.core.windows.net/base/path')"
+        )
+        self.validate_identity(
+            "CREATE OR REFRESH STREAMING TABLE csv_data (id INT, ts TIMESTAMP, event STRING) AS SELECT * FROM STREAM READ_FILES('s3://bucket/path', format => 'csv', schema => 'id int, ts timestamp, event string')"
+        )
