@@ -733,6 +733,11 @@ FROM x""",
         self.validate("TIME_TO_STR(x, 'y')", "DATE_FORMAT(x, 'y')", write="hive")
 
         self.validate("TIME_STR_TO_TIME(x)", "TIME_STR_TO_TIME(x)", write=None)
+        self.validate(
+            "TIME_STR_TO_TIME(x, 'America/Los_Angeles')",
+            "TIME_STR_TO_TIME(x, 'America/Los_Angeles')",
+            write=None,
+        )
         self.validate("TIME_STR_TO_UNIX(x)", "TIME_STR_TO_UNIX(x)", write=None)
         self.validate("TIME_TO_TIME_STR(x)", "CAST(x AS TEXT)", write=None)
         self.validate("TIME_TO_STR(x, 'y')", "TIME_TO_STR(x, 'y')", write=None)
@@ -845,7 +850,6 @@ FROM x""",
             "ALTER TABLE table1 RENAME COLUMN c1 TO c2, c2 TO c3",
             "ALTER TABLE table1 RENAME COLUMN c1 c2",
             "ALTER TYPE electronic_mail RENAME TO email",
-            "ALTER VIEW foo ALTER COLUMN bla SET DEFAULT 'NOT SET'",
             "ALTER schema doo",
             "ANALYZE a.y",
             "CALL catalog.system.iceberg_procedure_name(named_arg_1 => 'arg_1', named_arg_2 => 'arg_2')",
